@@ -1,6 +1,8 @@
 import json
 import shutil
 import os
+import xmltodict as xml
+import requests
 from urllib.request import urlopen
 import tarfile
 from typing import Callable, List, Union
@@ -62,30 +64,35 @@ def search(ps: Paperset, txt: Union[str, List[str]]) -> List[dict]:
 
 
 def download(dir: str = ".") -> None:
-    data = {
-        "comm_use_subset": "https://ai2-semanticscholar-cord-19.s3-us-west-2.amazonaws.com/2020-03-27/comm_use_subset.tar.gz",
-        "noncomm_use_subset": "https://ai2-semanticscholar-cord-19.s3-us-west-2.amazonaws.com/2020-03-27/noncomm_use_subset.tar.gz",
-        "custom_license": "https://ai2-semanticscholar-cord-19.s3-us-west-2.amazonaws.com/2020-03-27/custom_license.tar.gz",
-        "biorxiv_medrxiv": "https://ai2-semanticscholar-cord-19.s3-us-west-2.amazonaws.com/2020-03-27/biorxiv_medrxiv.tar.gz",
-        "metadata": "https://ai2-semanticscholar-cord-19.s3-us-west-2.amazonaws.com/2020-03-27/metadata_with_mag_mapping.csv",
-        "cas": "https://ai2-semanticscholar-cord-19.s3-us-west-2.amazonaws.com/antiviral_with_properties.sdf.gz",
-    }
+    site = xml.parse(
+        requests.get(
+            "https://ai2-semanticscholar-cord-19.s3-us-west-2.amazonaws.com/"
+        ).content
+    )["ListBucketResult"]["Contents"][::-1][:10]
+    key = [x["Key"] for x in site]
+    urls = [
+        f"https://ai2-semanticscholar-cord-19.s3-us-west-2.amazonaws.com/{k}"
+        for k in key
+    ]
+    keys = [k.split("/")[-1] for k in key]
+    data = dict(zip(keys, urls))
+
     if not os.path.exists(dir):
         os.mkdir(dir)
     for d in data.keys():
         print(f"downloading {data[d]}")
         handle = urlopen(data[d])
-        if d in os.listdir(f"{dir}"):
-            shutil.rmtree(f"{dir}/{d}", ignore_errors=True)
-        with open(f"{dir}/{d}.tar.gz", "wb") as out:
+        if d.replace(".tar.gz","") in os.listdir(f"{dir}"):
+            shutil.rmtree(f"{dir}/{d.replace('.tar.gz','')}", ignore_errors=True)
+        with open(f"{dir}/{d}", "wb") as out:
             while True:
                 dat = handle.read(1024)
                 if len(dat) == 0:
                     break
                 out.write(dat)
     for f in os.listdir(dir):
-        print(f"Extracting {dir}/{f}")
         if tarfile.is_tarfile(f"{dir}/{f}"):
+            print(f"Extracting {dir}/{f}")
             tar = tarfile.open(f"{dir}/{f}", "r:gz")
             tar.extractall(path=dir)
             tar.close()
